clear all
set mem 1000m
set maxvar 20000
set matsize 7000
capture log close
log using "gravity.log", replace

use dataset_def.dta

*PART A. Variable Generation

g limports=ln(imports)
g lgdp_o=ln(gdp_o)
g lgdp_d=ln(gdp_d)
g ldist= ln(distw)
g ltariff=ln(1+s_average)

la var limports "Ln(Imports)"
la var colony "Colonial link"
la var comlang_off "Common language"
la var ldist "Ln(distance)"
la var lgdp_d "Ln(GDP_importer)"
la var lgdp_o "Ln(GDP_exporter)"
la var ltariff "Ln(1+Tariff)"

qui tab imp, g(dimp)
qui tab exp, g(dexp)
qui tab pair, g(dpair)
qui tab year, g(dyear)



*PART B. Regression Specifications: Aggregated data  

tsset  pair  year

eststo: reg limports lgdp_d lgdp_o ldist contig colony comlang_off rta, robust
eststo: reg limports lgdp_d lgdp_o ldist contig colony comlang_off rta dyear*, robust
eststo: reg limports lgdp_d lgdp_o ldist contig colony comlang_off rta dimp* dexp*, robust
eststo: reg limports lgdp_d lgdp_o ldist contig colony comlang_off rta dimp* dexp* dyear*, robust
eststo: reg limports lgdp_d lgdp_o ldist contig colony comlang_off rta dpair*
esttab using regressions1, title (aggregate-dummy policy) se ar2 label replac rtf b(2) star (* 0.10 ** 0.05 *** 0.01) se(2) mti drop (dexp* dimp* dyear* dpair*)
eststo clear

reg limports lgdp_d lgdp_o ldist contig colony comlang_off ltariff dimp* dexp* dyear*, robust
esttab using regressions1, title (aggregate-tariff) se ar2 label replac rtf b(2) star (* 0.10 ** 0.05 *** 0.01) se(2) mti drop (dexp* dimp* dyear*) append






